# Majordome

General utilities for scientific Python and numerical simulation.

- [Majordome docs](https://wallytutor.github.io/python-majordome/)
- [Majordome on PyPI](https://pypi.org/project/majordome/)
